package net.grcomputing.opencms.search.lucene;

/*
* <p>
* This file is part of GRC's OpenCMS module library.
* </p>
* <p>
* GRC's OpenCMS module library 
* is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* </p>
* <p>
* GRC's OpenCMS module library is distributed in the 
* hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* </p>
* <p>
* You should have received a copy of the GNU General Public License
* along with GRC's OpenCMS module library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
* Or view the license online at http://www.gnu.org/licenses/gpl.html
* </p>
* <hr>
*/

/**
*  <p>This class implements a very fast tag stripper. It is not exactly 
* careful about stripping tags... it just rips them all out.</p>
* @author Matt Butcher mbutcher@grcomputing.net
* @see <a href="http://grcomputing.net">http://grcomputing.net</a>
*/
public class FastTagStripper {

	public static void main (String [] argv) {
		String html = "<html><head><title>Title</title><body attr='bogus'>Test  test      test \ntest test. This is a test.</body></html>";
		System.out.println(strip(html.toCharArray()));

	}

	/**
	 * Ruthlessly strips all tags out of a string. Not good if you are trying
	 * to capture data inside of the tags. Tags/Elements are considered
	 * anything that begins with a &gt;. Yes, this is pretty shallow, but it
	 * works, and it's fast. If you don't care about speed, look at the
	 * HTMLParser that comes with Lucene. 
	 * <p>Note that this will include contents of script or style tags that
	 * do not use comment tags to hide their contents.</p>
	 * <p>
	 * This will work for XML, too, but it will strip out the contents of 
	 * CDATA elements as well. 
	 * </p>
	 * @param char[] html
	 * @return String stripped of all tags/elements.
	 */
	public static String strip(char [] doc) {
		StringBuffer sb = new StringBuffer();
		char lastChar = ' '; // basically, prevents leading whitespace
		boolean write = true;
		for (int i=0; i < doc.length; ++i) {
			if(doc[i] == '<') write = false;
			else if (doc[i] == '>') {
				write = true;
				sb.append(' ');
			} else if (write && 
					!(isWhitespace(doc[i]) && isWhitespace(lastChar))) {
				sb.append(doc[i]);
			}
			lastChar = doc[i];
		}
		return sb.toString();
	}

	public static boolean isWhitespace(char c) {
		char [] ws = {' ','\n','\t'};
		for (int i = 0; i < ws.length; ++i) {
			if(ws[i] == c) return true;
		}
		return false;
	}
}



