package net.grcomputing.opencms.search.lucene;

/*
* <p>
* This file is part of GRC's OpenCMS module library.
* </p>
* <p>
* GRC's OpenCMS module library 
* is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* </p>
* <p>
* GRC's OpenCMS module library is distributed in the 
* hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* </p>
* <p>
* You should have received a copy of the GNU General Public License
* along with GRC's OpenCMS module library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
* Or view the license online at http://www.gnu.org/licenses/gpl.html
* </p>
* <hr>
*/

import java.util.HashMap;

import org.apache.lucene.document.Document;

import com.opencms.core.CmsException;
import com.opencms.file.CmsFile;
import com.opencms.file.CmsObject;

/**
* <p>All implementations of OpenCMS Document-building classes must implement
* this interface.</p>
* <p>This interface provides a framework for building Documents in a way that
* they can be used within OpenCMS. Documents are used by the Lucene search
* engine to build intelligent representations of data. Documents vary from
* source to source (e.g. there is a different Document representation for a Page
* than for a JSP), and extensions to the core document types for OpenCMS might 
* require a new Document factory.</p>
* <p><b>Make sure your implementation is thread safe.</b> No attempt is made
* to synchronized hits to the Document method. ALSO, the Document methods
* may be called any number of times on one instance of the object.</p>
* @author Matt Butcher mbutcher@grcomputing.net
* @see <a href="http://grcomputing.net">http://grcomputing.net</a>
*/
public interface I_DocumentFactory {
	/**
	 * Takes a CmsFile instance and builds a Lucene Document suitable for 
	 * index generation.
	 * @param CmsObject cms - instance of CmsObject
	 * @param CmsFile f - file that we will generate Document from.
	 * @throws CmsException it cannot work with the CmsFile or CmsObject.
	 */
	public Document Document(CmsObject cmso, CmsFile f)
		throws CmsException ;

	/**
	 * Takes a CmsFile instance and builds a Lucene Document suitable for 
	 * index generation. Allows extra parameters to be passed in via the
	 * params HashMap.
	 * @param CmsObject cms - instance of CmsObject
	 * @param CmsFile f - file that we will generate Document from.
	 * @param HashMap params - a collection of parameters
	 * @throws CmsException it cannot work with the CmsFile or CmsObject.
	 */
	public Document Document(CmsObject cmso, CmsFile f, HashMap params)
		throws CmsException ;
}
