package net.grcomputing.opencms.search.lucene;
/*
* <p>
* This file is part of GRC's OpenCMS module library.
* </p>
* <p>
* GRC's OpenCMS module library 
* is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* </p>
* <p>
* GRC's OpenCMS module library is distributed in the 
* hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* </p>
* <p>
* You should have received a copy of the GNU General Public License
* along with GRC's OpenCMS module library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
* Or view the license online at http://www.gnu.org/licenses/gpl.html
* </p>
* <hr>
*/
import java.util.HashMap;

import org.apache.lucene.document.Document;

import com.opencms.core.CmsException;
import com.opencms.file.CmsFile;
import com.opencms.file.CmsObject;

/**
* <p>This class serves as a document factory for OpenCMS resources. It produces
* Lucene Document objects that contain the correct fields for indexing OpenCMS
* resources. Unlike some of the other Lucene implementations, this one is
* highly coupled with the OpenCMS API - thereby taking advantage of properties
* security settings, etc.</p>
* <p>Essentially, the main purpose of this method is to provide factories for
* Document instances that are specific to the types of resources in OpenCMS.
* For instance, we know that a Page will have a name, a title, and probably
* description and keywords. We also know that it is an XML document with HTML
* stored in the CDATA section. These bits of information provide information
* that we can use to generate an appropriate Document representation.</p>
* @author Matt Butcher mbutcher@grcomputing.net
* @see <a href="http://grcomputing.net">http://grcomputing.net</a>
*/
public class JspDocument implements I_DocumentConstants, I_DocumentFactory {
	/**
	 * Right now, this is just a convenience function that calls 
	 * BodylessDocument. In the future, this may be extended to grab
	 * pCDATA out of the body for indexing (e.g. to search for text at the 
	 * beginning of a form field.). Generally, it is not advisable to 
	 * search JSP pages unless you know for a fact that they can be called
	 * correctly from a search engine link.
	 *
	 * @param CmsObject cms - instance of CmsObject
	 * @param CmsFile f - file that we will generate Document from.
	 * @throws CmsException it cannot work with the CmsFile or CmsObject.
	 */
	public Document Document(CmsObject cmso, CmsFile f)
		throws CmsException 
	{
		return (new BodylessDocument()).Document(cmso,f);
	}

	/**
	 * Right now, this is just a convenience function that calls 
	 * BodylessDocument. In the future, this may be extended to grab
	 * pCDATA out of the body for indexing (e.g. to search for text at the 
	 * beginning of a form field.). Generally, it is not advisable to 
	 * search JSP pages unless you know for a fact that they can be called
	 * correctly from a search engine link.
	 *
	 * @param CmsObject cms - instance of CmsObject
	 * @param CmsFile f - file that we will generate Document from.
	 * @param HashMap params
	 * @throws CmsException it cannot work with the CmsFile or CmsObject.
	 */
	public Document Document(CmsObject cmso, CmsFile f, 
		HashMap params)
		throws CmsException 
	{
		return (new BodylessDocument()).Document(cmso,f,params);
	}
}



